docs.rs failed to build auv-driver-linux-0.0.22
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
AUV Driver Linux
from @kwaa:
This Driver function is not yet complete and takes my desktop environment as priority (GNOME Wayland + PaperWM, see SN0WM1X OS for details)
Only supporting Wayland is expected, please do not do X11 adaptation to avoid making the code more difficult to maintain.
But if you use KDE / Niri / Hyprland, you are also welcome to try the adaptation!